/**
 *
 *  BibSonomy-Rest-Client - The REST-client.
 *
 *  Copyright (C) 2006 - 2013 Knowledge & Data Engineering Group,
 *                            University of Kassel, Germany
 *                            http://www.kde.cs.uni-kassel.de/
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package org.bibsonomy.rest.client.queries.get;

import org.bibsonomy.common.enums.GroupingEntity;
import org.bibsonomy.model.Tag;
import org.bibsonomy.rest.RESTConfig;
import org.bibsonomy.rest.client.AbstractQuery;
import org.bibsonomy.rest.exceptions.BadRequestOrResponseException;
import org.bibsonomy.rest.exceptions.ErrorPerformingRequestException;
import org.bibsonomy.util.UrlBuilder;

/**
 * Use this Class to get information about the specified concept
 * 
 * @author Stefan Stützer
 * @version $Id: GetConceptDetailsQuery.java,v 1.14 2013-05-31 15:59:00 mme Exp $
 */
public class GetConceptDetailsQuery extends AbstractQuery<Tag> {

	private final String conceptname;
	private String groupingName;
	private GroupingEntity grouping = GroupingEntity.ALL;
	
	public GetConceptDetailsQuery(final String conceptName) {
		this.conceptname = conceptName;
		this.downloadedDocument = null;
	}
	
	@Override
	protected Tag doExecute() throws ErrorPerformingRequestException {
		UrlBuilder urlBuilder;
		
		switch (this.grouping) {
		case USER:
			urlBuilder = new UrlBuilder(RESTConfig.USERS_URL);
			urlBuilder.addPathElement(this.groupingName);
			urlBuilder.addPathElement(RESTConfig.CONCEPTS_URL);
			urlBuilder.addPathElement(this.conceptname);
			break;
		case GROUP:
			throw new UnsupportedOperationException("Grouping " + grouping + " is not implemented yet");
			//url = URL_GROUPS + "/" + this.groupingName + "/" + URL_CONCEPTS + "/" + this.conceptname;
			//break;
		case ALL:
			urlBuilder = new UrlBuilder(RESTConfig.CONCEPTS_URL);
			urlBuilder.addPathElement(this.conceptname);  
			break;			
		default:
			throw new UnsupportedOperationException("Grouping " + grouping + " is not available for concept details query");
		}
		
		this.downloadedDocument = performGetRequest(urlBuilder.asString());
		return null;
	}

	@Override
	public Tag getResult() throws BadRequestOrResponseException, IllegalStateException {
		if (this.downloadedDocument == null) throw new IllegalStateException("Execute the query first.");
		return this.getRenderer().parseTag(this.downloadedDocument);
	}
	
	public void setUserName(final String userName) {
		this.groupingName = userName;
		this.grouping = GroupingEntity.USER;
	}
	
	public void setGroupName(final String groupName) {
		this.groupingName = groupName;
		this.grouping = GroupingEntity.GROUP;
	}	
}